#
# spec file for package guitarix
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _lto_cflags %{nil}
%bcond_with ladspa

Name:           guitarix
Version:        0.46.0
Release:        1.7
Summary:        Simple Linux amplifier for jack
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://guitarix.sourceforge.net/
Source:         https://github.com/brummer10/guitarix/releases/download/V%{version}/guitarix2-%{version}.tar.xz
# Patches from Fedora
# Patch0:         guitarix-cstdint-include.patch
# Patch1:         guitarix-mismatched-delete.patch
# Patch2:         guitarix-python-3.11-ftbfs.patch
BuildRequires:  fdupes
%if 0%{?suse_version} <= 1600
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  gperf
BuildRequires:  intltool
BuildRequires:  libboost_context-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
%if %{with ladspa}
BuildRequires:  ladspa-devel
%endif
BuildRequires:  google-roboto-fonts
BuildRequires:  pkgconfig
BuildRequires:  sassc
BuildRequires:  update-desktop-files
BuildRequires:  zita-convolver-devel
BuildRequires:  zita-resampler-devel
BuildRequires:  pkgconfig(avahi-gobject)
BuildRequires:  pkgconfig(bluez)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(fftw3l)
BuildRequires:  pkgconfig(gail)
BuildRequires:  pkgconfig(glibmm-2.4) >= 2.56
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk+-unix-print-3.0)
BuildRequires:  pkgconfig(gtk+-x11-3.0)
BuildRequires:  pkgconfig(gtkmm-3.0)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(liblo)
BuildRequires:  pkgconfig(libsass)
BuildRequires:  pkgconfig(lilv-0)
BuildRequires:  pkgconfig(lrdf)
BuildRequires:  pkgconfig(lv2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sigc++-2.0)
BuildRequires:  pkgconfig(sndfile)
Requires:       meterbridge
Requires:       vorbis-tools
Requires:       (jack or pipewire-libjack-0_3)
Recommends:     bestplugins
Recommends:     lv2-%{name}
%if %{with ladspa}
Recommends:     ladspa-%{name}
%endif

%description
guitarix is a simple mono amplifier to jack with one input and two
outputs. Designed to get nice trash/metal/rock/guitar sounds.

Available are the controls for bass, treble, gain, balance,
distortion, freeverb, impulse response (pre state), crybaby(wah),
feedback/feedforward-filter and echo. A fixed resonator will use,
when distortion is disabled.

%package -n libgxw0
Summary:        Guitarix runtime library
Group:          System/Libraries

%description -n libgxw0
guitarix is a simple mono amplifier to jack with one input and two
outputs.

%package -n libgxwmm0
Summary:        Guitarix runtime library
Group:          System/Libraries

%description -n libgxwmm0
guitarix is a simple mono amplifier to jack with one input and two
outputs.

%if %{with ladspa}
%package -n ladspa-%{name}
Summary:        Guitarix - ladspa plugins
Group:          Productivity/Multimedia/Sound/Utilities

%description -n ladspa-%{name}
guitarix is a simple mono amplifier to jack with one input and two
outputs. Designed to get nice trash/metal/rock/guitar sounds.

Available are the controls for bass, treble, gain, balance,
distortion, freeverb, impulse response (pre state), crybaby(wah),
feedback/feedforward-filter and echo. A fixed resonator will use,
when distortion is disabled.

This package contains the  LADSPA plugins (UniqID 4061 - 4068).
%endif

%package -n lv2-%{name}
Summary:        Guitarix - LV2 plugins
Group:          Productivity/Multimedia/Sound/Utilities

%description -n lv2-%{name}
guitarix is a simple mono amplifier to jack with one input and two
outputs. Designed to get nice trash/metal/rock/guitar sounds.

Available are the controls for bass, treble, gain, balance,
distortion, freeverb, impulse response (pre state), crybaby(wah),
feedback/feedforward-filter and echo. A fixed resonator will use,
when distortion is disabled.

This package contains the LV2 plugins.

%package -n bestplugins
Summary:        Best Mega Pack 1+3
Group:          Productivity/Multimedia/Sound/Utilities

%description -n bestplugins
Bestplugins Mega Pack 1+3 contains dozens of guitar sounds from famous bands.

%prep
%autosetup -n guitarix-%{version} -p1

%build
%if 0%{?suse_version} <= 1600
export CC=gcc-12
export CXX=g++-12
%endif
for i in `grep -rl "/usr/bin/env python"`;do sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i} ;done
export LDFLAGS="-ldl"
./waf configure -v --faust \
                   --libdir=%{_libdir} \
                   --includeresampler \
                    --no-faust \
%if %{with ladspa}
                   --ladspadir=%{_libdir}/ladspa  \
                   --ladspa \
                   --new-ladspa \
%endif
                   --prefix=%{_prefix} \
                   --cxxflags="%{optflags} \
%ifarch %ix86
                   -mfxsr \
%endif
                   -std=gnu++0x -fpermissive"
./waf build -v %{?_smp_mflags}

%install
./waf install --destdir=%{buildroot}
%suse_update_desktop_file -i %{name} AudioVideo Music
%find_lang %{name}
# No header files installed for this lib
rm -f "%{buildroot}/%{_libdir}/"*.so

%fdupes -s %{buildroot}/%{_datadir}/gx_head/
%fdupes -s %{buildroot}/%{_libdir}/lv2/

%post   -n libgxw0 -p /sbin/ldconfig
%postun -n libgxw0 -p /sbin/ldconfig

%post   -n libgxwmm0 -p /sbin/ldconfig
%postun -n libgxwmm0 -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root)
%doc changelog README
%license COPYING
%dir %{_datadir}/gx_head
%{_bindir}/%{name}
%{_datadir}/gx_head/*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/gx_head*.png
%{_datadir}/pixmaps/gx_bypass.png
%{_datadir}/pixmaps/gx_off.png
%{_datadir}/pixmaps/gx_on.png
%{_datadir}/pixmaps/gx_log_grey.png
%{_datadir}/pixmaps/gx_log_red.png
%{_datadir}/pixmaps/gx_log_yellow.png
%{_datadir}/pixmaps/gx_splash.png
%{_datadir}/pixmaps/insert_off.png
%{_datadir}/pixmaps/insert_on.png
%{_datadir}/pixmaps/jackd_off.png
%{_datadir}/pixmaps/jackd_on.png
%{_datadir}/metainfo/org.guitarix.guitarix.metainfo.xml

%files -n libgxw0
%defattr(-,root,root)
%{_libdir}/libgxw.so.0
%{_libdir}/libgxw.so.0.1

%files -n libgxwmm0
%defattr(-,root,root)
%{_libdir}/libgxwmm.so.0
%{_libdir}/libgxwmm.so.0.1

%files -n lv2-%{name}
%defattr(-,root,root)
%{_libdir}/lv2/

%if %{with ladspa}
%files -n ladspa-%{name}
%defattr(-,root,root)
%dir %{_libdir}/ladspa
%{_libdir}/ladspa/*.so
%dir %{_datadir}/ladspa
%dir %{_datadir}/ladspa/rdf
%{_datadir}/ladspa/rdf/%{name}_amp.rdf
%{_datadir}/ladspa/rdf/%{name}.rdf
%endif

%files -n bestplugins
%defattr(-,root,root)
%dir %{_datadir}/gx_head/sounds/bands/

%changelog
* Mon Mar 11 2024 Konstantin Voinov <kv@kott.no-ip.biz>
- update to version 0.46.0
- use gcc12 for Leap
- drop patches, now fixed in upstream:
  guitarix-cstdint-include.patch
  guitarix-mismatched-delete.patch
  guitarix-python-3.11-ftbfs.patch.
- 0.46.0 changes:
  * Add support for RTNeural network engine
  * Allow to load two instances of the neural modules
  * Add NAM and RTNeural Multi module (Load two models and blend
    between them)
  * Implement links in the about menu to download sites for neural
    models (*.nam or *.aidax)
  * Fix resampling issues within the neural modules
  * Fix for distributors: reimplement root directory for release tarball
- 0.45.0 changes:
  * fix various bugs since the last release from May 2, 2022
  * introduce support for the outstanding Neural Amp Moduler
* Fri Mar 31 2023 Dave Plater <davejplater@gmail.com>
- Added patches from fedora one of which fixes Factory build
  without ladspa plugins. Disabled ladspa plugin build until a fix
  is found.
- Patches added: guitarix-cstdint-include.patch,
  guitarix-mismatched-delete.patch and
  guitarix-python-3.11-ftbfs.patch.
* Mon May  2 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- update .spec
- update to version 44.1
    Fix race condition when build with Faust
  Changelog for 0.44.0:
    Fix save behavior under NSM control
    Fix allow changing base frequency for tuner
    Re-enable gainline edit for convolver
    Remove dependency on glibmm for LV2 plugs (by Hubert Figuière)
    Fix build when LTO is in use
    Fix wrong max value for Tube Model in gx_amp LV2 plugins (by kramlie)
    Fix build with new glib version (issue with volatile keyword)
    Update to new Faust version 2.40.0
    Please use the attached guitarix2-0.44.1.tar.xz
  Changelog for 0.43.1
    Fix Install metainfo in prefix (by Hubert Figuière)
    Fix GxAmplifierX produces weird noise after buffer size changes
  Changelog for 0.43.0
    Fix build on gcc 11
    Add Fizz Remover
    Implement option to enable jack session support (--jack-session)
    Fix Unnatural decay at high gain (palm mutes)
    Fix Fuzz Face Mayer
    Add 41 tet tuner option (by Tristan Tarrant)
    Fix GxAmplifiers cycling through cabinets/pre-amps/tubes is skipping items
    Remove glibmm dependency from LV2 plugs
    Update used faust version to 2.37.3
    Add option in GxAmplifiers to allow switch between Bass/Guitar input
    Add metadat.xml file
    Add X-NSM-Capable entry in .desktop file
* Fri May 28 2021 Mark Trompell <mark@marktrompell.de>
- Add pipewire-libjack-0_3 as an alternative requirement
* Wed Apr 28 2021 Dave Plater <davejplater@gmail.com>
- Used -fpermissive flag to fix factory build.
* Fri Dec 25 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Update to 0.42.1
  * Make new Output Limiter less conservative
  * Add Indicator Widget for the Limiter to show limiting levels
  * Increase range for Volume controls on the Power Amp plugin
  * Fix MultiBandDistortion introduce sonic noise
  * Add Limiter to the Ladspa plugin
  * Add configure option to build and link libgxw(mm) statically
* Fri Dec 25 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Delete obsolete patches: fpexception.patch, guitarix-boost69.patch
  and  guitarix-fix-cannot-select-non-users-preset.patch
- Update to 0.42.0
  * For this release Damien Zammit from ZamAudio has reworked our
    tube emulation. This improved beside the overall sound, the
    dynamic responses of the different tube simulations.
    Be aware please, that this may break your existing presets, but,
    we believe that the improvement in sound is it worse to force
    you to readjust your presets to match the new tube sims.
  * Reworked French translation by Olivier Humbert
  * Add DC-Blocker on the Input
  * Add Output Limiter
  * Add Volume controls for the Power Amp plugin
  * Fix version checks for needed packages
  * Fix several small Bugs and hopefully don't introduce to much new ones
* Fri Dec  4 2020 Konstantin Voinov <kv@kott.no-ip.biz>
- Add guitarix-fix-cannot-select-non-users-preset.patch fixes #21
- Use proper lto disablement
* Sun Nov 22 2020 Dave Plater <davejplater@gmail.com>
- Update to version 0.41.0 and fix build by removing -flto=auto
  from the build.
- Upsteream changes:
  * Add Slovak translation by Jozef Riha
  * Fix issue #104 lv2 plugins contains executable stack, patch by
  Alexander Tsoy
  * Fix issue #105 Compile error on 0.40.0
  * Fix issue #109 cannot initialize a variable of type 'char '
  with an rvalue of type 'void '
  * Fix issue #110 error: unknown type name 'va_list'
  * Add NSM support
  * Add midi out for tuner
  * Add low/high cut filter before tuner
  * GxTuner set to use same precision then the tuner in guitarix
  * Use tabbox for LV2 plugs with to much controlls
  * Disable GxVibe, because it is brocken
  * Fix several Bug's and hopefully don't introduce to much new
  one's
  * Port GUI and underlying lib's (gxw/gxwmm) to GTK3 (gtkmm3)
  * Port LV2 plugin GUI's to X11/cairo
  * Add Midi feedback support
  * Add new PowerAmp modul
* Thu Jan 16 2020 Dave Plater <davejplater@gmail.com>
- Update to 0.39.0, now builds with python3
- Rebased guitarix-boost69.patch
- Some upstream changes:
  * fix bug #67, dont use malloc.h on FreeBSD
  * remove assert for ports count, to allow save removing of changed
  LV2 plugins
  * add new option -E --hideonquit, this makes the UI experience
  smooth when used as LV2 plugin
  * add support for LV2_URID_Map, LV2_URID_Unmap and LV2_OPTIONS to
  allow more plugs to load
  * fix compiler warnings with gcc 8
  * add exit handler and warning when samplerate is above 96kHz
  * hide splash on error message
  * set online help to sourcforge/discussion
  * add Russian-language translation by Valeriy Shtobbe and
  Olesya Gerasimenko, many thanks!
  * update all build scripts to use faust version 2.15.11 and update
  all generated faust files
* Wed Mar 20 2019 plater <davejplater@gmail.com>
- Update to 0.37.3 and fix build against boost1_69 with patch:
  guitarix-boost69.patch
- Package libgxw and libgxwmm in their own subpackages.
- Upstream changes since 0.36.1 for earlier changes see changelog:
  * add support for zita-convolver4.
  * implemented "Thick Distortion" plugin by Viacheslav Lotsmanov.
  * switch to use libcurl for download online presets.
  * point online help to reddit/guitarix.
  * add direct output unit for drumsequencer (bypass rack).
  * add overdubbing to live looper.
  * add direct output support to live looper.
  * add midi channel selector, fix bug #64.
  * new plug Ampimpulse-stereo.
  * fix Live Looper freezes the remote UI.
  * fix Tuner stick is not saved in remote UI.
  * fix DrumSequencer remote UI.
  * fix rc files for older clearlooks engine.
  * fix disable online preset download in remote UI.
  * fix GxDigitalDelay sync BPM when UI is not shown.
  * add new commandline switch (_d, --disable-multi-client)
    to allow running guitarix as single client application.
  * fix portmap when running as single client.
  * again some fixes and additions on the DK_simulator
    contributed by Yoann Le BORGNE.
* Sat Dec 23 2017 davejplater@gmail.com
- Fix Factory build by requiring python2
* Wed Oct 11 2017 davejplater@gmail.com
- Fix boost-devel bug boo#1062780
* Mon Apr  3 2017 davejplater@gmail.com
- Update to version 0.35.3 - fixes gcc7 build
- Upstream changes:
  * add labels tp some LV2 plugs
  * fix fastmeter tickness in LV2 UI's
  * supress wrong compiler warnings array-bounds in jcm800pre
  * fix typo in gx_mbcompressor.lv2/modgui.ttl
  * add Relief to buttons
  * big commit of all faust files regenerated, new dsp2cc script
  * new version of gx_sceleton.lv2 and make_lv2_bundle.sh
  * fix compiler warning in rack.cpp
  * fix volume difference between 44.1khz and 96khz reported by
  * fix gx_livelooper.lv2 gain controller
  * fix jcm800pre on 96khz
  * fix bug #35 abs(uint32_t) is nonsensial and ill-formed
  * fix bug #36 std::abs used without include relevant header
  * fix Glib-GObject-CRITICAL when unref "liststore2"
  * use new togle state logic as well for toggle_type::OnOff
  * fix oversampling  presence
  * make file chooser blook free
  * correct phase on oscilloscope
  * use 96khz internal for presence unit
  * fix gx_vibrochump vibe selector direction
  * more vowel mutation checks
  * correct version of midknob in libgxw
  * add new vibe label for gx_vibrochamp.lv2
  * add On/Off switch for the vibe in gx_vibrochump
  * fix gx_jcm800pre lv2 plugs for the use in ardour
  * more vowel mutations
  * more vowel mutation protection
  * extend protection for vowel mutation in preset names
  * fix vibrochump max depth and redeye.ttl file
  * fix GxRedeye Vibro Champ for use with generic UI.
  * apply patch set from Valentin Vidic to start presets numbered
    by 0
  * apply changed_midi.patch from Valentin Vidic (thanks)
* Tue Feb 28 2017 sfalken@opensuse.org
- Update to 0.35.2 fixes buildfailure in openSUSE:Factory (boo#1023724)
- Remove guitarix-0.35.0-gcc6.patch  Fixed with 0.35.2 release
- Update to 0.35.2:
  * add stereo cabinet plugin
  * fix Bypass insert jack port with midi CC
  * fix insert bypass logic
  * add scroll wheel support to status images
  * add menu option to set a midi controller for engine bypass
  * switch to use glib-compile-resources instead gdk-pixbuf-csource to include images into libgxw.
  * replace deprecated gdk_pixbuf_new_from_data by gdk_pixbuf_new_from_resource
  * add new configure option --generate-resources to force re-generation of resource file (default=off)
  * fix names in GtkIconFactory
  * some re-generated plugs
  * remove G_GNUC_##_IGNORE_DEPRECATIONS macro, don't need it anymore
  * Fix Preset switching issue in lv2 amps and cabinet
  * disable midi control for un-loaded plugs
  * add check if LV2 ports are valid
  * change color for Error Box
  * add scriptset to simplify the build of LV2 plugs from gschem files
  * fix forgotten replace of Effect in generated ttl file
  * fix type in make_lv2_bundle.sh
  * fix (sf#p/guitarix/bugs/34)
  * fix build with gcc6
- Update to 0.35.1:
  * Add op777 SPICE model instead of removed with incorrect license and regenerate .lib script
  * Add oc_2 plugin to build script
  * Preset online window size
  * fix build with GCC6
  * fix icon size of widget-gxwidgets-gxhslider.png
  * fix range of graphic eq
  * add support for nominalBlockLength in GxAmps.lv2 and
  GxCabinet.lv2
  * fix base color in GtkTreeView
  * prepare to enable faust-0.9.73 as good version
  * commit faust sources, prepared and regenerated with faust-0.9.73
  * implement presence level as dry/wet control (smooth level change)
  * smooth level control for cabinet and amp impulse plugins
  * Aluminium theme: new textures
  * New Theme: Hippie
  * New Themes: grungy sun, grungy sun dark, grandma, psychedelic
  * remove debug print statement from dsp2cc tool
  * revert latest changes in presence, cabinet and ampimpulse control
  * enable smooth logo change (move logo draw to paintbox class)
  * add two new styles "Plain Dark" and "Nebula"
  * apply patch from rabit Fix: QWebView on android don't have localStorage
  * apply patch from rabit Fix: Port should be obtained from the current location
  * allow file browsing with remote interface
  * resolve hostname for folebrowsers in remote UI
  * add BassBoom plugin (sub-bass harmonics)
  * some rework on the fuzz plugins
  * add forgotten file bassboom.cc
  * revert changes in fuzz faces
  * add tooltip to the Master Volume controller
  * add plugin id to message about detected DENORMALS
* Tue Jul  5 2016 jengelh@inai.de
- Drop "devel" subpackage, there are no devel files in it.
* Sun Jul  3 2016 i@marguerite.su
- add patch guitarix-0.35.0-gcc6.patch, fixed boo#985365
  * fix call of overloaded 'abs(double)' is ambiguous
* Sun May  8 2016 sflees@suse.de
- Update to 0.35.0
  * New UI
  * Many new and improved plugins
- Remove guitarix-0.28.2-gperf_tmpl-fix.patch (included upstream)
* Sun Jun 28 2015 tjcw@physics.org
- fpexception.patch: gcc5 supports proper FP exception handling, so we
  have to take out the dummy exception handling that was in the headers
* Fri Jan 16 2015 p.drouand@gmail.com
- Update to version 0.32.2
  * fix some rcstyle bugs for gtk-2.24.25 and maybe fixed for KDE
  * allow load of preset-files witch contain Denormal Numbers (flush to zero)
  * add warning when denormal value found in preset file
  * if parameter is out of range, set it to the default value
  * add missing Icons to glade-gxw
  * add wavesharper plugin
  * use long int to compare regions size in gx_mlock.cc -> (Gcc: 4.9.2)
- Use download Url as source
- Add pkgconfig(bluez), pkgconfig(eigen3) and pkgconfig(lilv-0) to
  requirements; new upstream dependencies
* Fri Mar 28 2014 stephan.barth@suse.com
- removed deprecated guitarix2-missing_libdl.diff
- added guitarix-0.28.2-gperf_tmpl-fix.patch which fixes some C++ compilations
  issues
- update from version 0.19.0 to version 0.28.3 which adds a lot of features
  and files which makes package splits inevitable:
  - a devel package with the libraries
  - a lv2 package
  - bestplugins which contains files for getting the guitar sound from famous
    bands
- see the accompanying changelog for a detailed list of changes
- fixed typos in package descriptions
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Oct 12 2011 mseben@gmail.com
- added guitarix2-missing_libdl.diff to fix build
- update to guitarix2-0.19.0
  * make convolver a rack module
  * add favourite list menu to the convolver
  * add zita-rev1 module (from faust distribution)
  * add stereo verb module
  * add some cabinet`s
  * fix bug in Ladspa plugins
  * add factory settigs by JP
  * made logger window resizeable
  * tuned switching of configurations without loud bang
  * plugged some memory leaks in rack order code (GList's not freed)
  * bug fix: GxScrollBox passed an uninitialized group to RadioButtons
  * introduce a plug-in based engine
  * a couple of invisible internal source changes and a couple of new development
  tools added
  * switch to use faust version 0.9.43
  * other small / big clean-ups
* Wed Aug 10 2011 mseben@gmail.com
- updated to guitarix2, it is a full replacement for
  guitarix and/or gx_head in any sense,
  changes in guitarix (0.18.0):
  * add tube model 12AT7
  * fix runtime isuess when build with g++ > 4.5
  * add presence level controller
  * add bass booster level controller
  * switch to function pointer based engine
  * fix isuess with GtkBuilder > 2.14
  * fix correct use of included zita-resampler source
  * add factory settings by a5Rutoandimat
  changes in guitarix2 (0.17.0) unstable
  * fix jack session support
  * add 2 new amp models
  * fix some speeling errors (patch by merlinthegreen)
  * sorce code formating and cleanup (Google C++ Style Guide)
  changes in gx-head (0.14.0)
  * add tube 6DJ8
  * add clean tube modes
  * reworked drive controller (bypass <-> wet)
  * add clipper
  * add mono level controller
  * add French translation by jy
  * add TACTILE skin by Pete Shorthose
  * add knob animation support by Pete Shorthose
  * add new knob images by Pete Shorthose
  * add new switch images by Pete Shorthose
  * fix 64bit bug in libgxw by Pete Shorthose
  * add factory settings by Dave Phillips
  * add 3bad EQ + sharper
  * add tremolo by transmogrifox (Rakarrack)
  changes in gx-head (0.13.0)
  * add post amp
  * add noise gate
  * add italian translation by 	Ivan Tarozzi
  * add desert skin by zettberlin
  * add factory settigs by zettberlin
* Fri Aug 27 2010 mseben@gmail.com
- updated to 0.11.1
  * fix Bug Echo/Chorus/Delay/Slooper dont work
  * add pre/post processing switch to all mono Effects
* Wed Aug  4 2010 mseben@gmail.com
- updated to 0.11.0
  * new version of the impulse response parameter editor. You can
    now graphically define a gain line to be applied to the IR data,
  * the multi-line distortion effect now has 4 frequency bands and
    is better optimized
  * fix regression from version 0.10.0: now the default preset file is
    created again if it doesn't exist (e.g. in new installations).
  * changes that might be interesting for Developers:
    Guitarix team put the Guitarix widgets into a library, with the goal of
    making them usable independently from Guitarix. You can build
    it as shared library and there's a c++ (gtkmm) wrapper, a python
    wrapper and glade support.
* Sun Jul 11 2010 mseben@novell.com
- updated 0.10.0
  * add tonestack models
  * add 2. amp model
  * add cabinet impulse response modul
  * add Patch Info widget
  * add Preset File Load/Export option
  * add simple looper
  * add Oscilloscope and tuner state to main settings
  * selectable distortion model (multi/single line)
  * selectable EQ model (fixed/scalable freq)
  * free mem when not used (delay lines)
  * reworked Gui
  * fix varios bugs
* Thu Jul  8 2010 mseben@novell.com
- updated to 0.09.0
  * make distortion a multiband distortion
  * fix bug in resample IR-files
  * resample IR-files now on-the-fly
  * add insert point ports to the effect chain
  * add --optimization flag for configure the build
  * switch to double precision instead of single precision
  * fix bug in reconfigure convolver when preset change
  * add patch from Peder Hedlund, build against gtk-2.12.9 and gcc-4.3.1
  * add faust 0.9.24 to the "good_faust_versions"
* Thu May 27 2010 mseben@novell.com
- updated to 0.08.0
  * new portmap window
  * add Quad Filter
  * add Moog Filter
  * add Flanger
  * add new post processing tube3
  * add two 10 band parametric EQ's
  * add oversample mode selector
  * fix some bugs in midi out
  * reworked tuner interface (show frequency(hz))
  * add new configure options (see ./waf --help form more info)
- changes in guitarix 0.07.1
  * version check of ~/.guitarix was commented out
- changes in guitarix 0.07.0
  * nearly complete reworked source by Andreas Degert
  * amp and effect units based direct on faust expressions
  * all faust sources included
  * new accumulated tuner unit with new interface (analogue Style needle meter)
  * Midi controller connections could saved with in presets and/or general
  * a editable Midi controller map  is available
  * new human readable preset style
  * knobs could be used like sliders (press ctrl + mouse-button
    and move the mouse horizontal, leave the ctrl and hold mouse-button
    for fine tune), or like real knobs (turn them around)
  * convolution unit based on zita-convolver is now integrated in the engine
  * presets could change with Midi Program Messages
* Wed Mar 10 2010 mseben@novell.com
- updated to guitarix 0.06.0
  * bug fix for multi core build
- changes in version 0.05.9-1
  * add Midi learn support
  * add amp chooser
  * fix and posible add some Bugs
* Fri Jan  8 2010 mseben@novell.com
- updated to guitarix 0.05.8-1
  * fix memory leak
  * add multi band filter
- changes in version 0.05.7-1
  * fix name mixmatch for jconvolver
- changes in version 0.05.6-1
  * optimize Gui thread
  * add delay unit
  * put effects in a scrollbox
  * varius bug fixes
  * set dependency finaly down to Gtk+2.12
* Thu Dec 17 2009 mseben@novell.com
- updated to 0.05.5-1
  * make effects moveable
  * set dependency down to Gtk+2.12
- changes in version 0.05.4-1
  * performace boost by remove float to int casts from engine
  * reorder GUI
- changes in version 0.05.3-1
  * quick update to cover renaming of jconv to jconvolver
- deprecated static_instance.diff patch
* Mon Nov 30 2009 mseben@novell.com
- updated to 0.05.2-1
  * remove dependency of the boost library
  (Many thanks to "thrasher13b" for the patch)
  * fix missing "./" in ./debian/rules reported
  by GMag (AV Linux)
  * add 2 Channel gain and delay chooser to the
  Jconv settings widget.
  * add scroll/zoom mode to the wave view
  * reworked Jconv settings widget UI
  * various GUI and feature clean-up's
* Sun Nov 29 2009 mseben@novell.com
- added static_instance.diff : fix build issues with undefined
  static member functions "instance"
* Thu Nov  5 2009 mseben@novell.com
- updated to 0.05.1-1
  * new jack/port/server connect/monitor/control features
  * new level meters
  * new noise gate, noise sharper, chorus, bass booster
  * new gain control for the jconv input
  * reworked jconv settings widget
  * a bit polish the GUI
  * new skins and reworked skin menu
  * various bug fixes
* Wed Aug 26 2009 mseben@novell.com
- fixed version of GPL license
* Sat Aug  8 2009 mseben@novell.com
- initital openSUSE buildservice, used spec from Toni Graffy <toni@links2linux.de
- updated to 0.05.0-1
  * add keyboard shortcuts
  * new code structure by James
  * impruved skin handling
  * add middle tone control
  * reworked audio engine
  * add bypass mode
  * add logging window
  * add engine state widget
- spec rewritten for waf build system
- added patch for gtk 2.14.4 in openSUSE_11.1 (doesn't contain gtk_menu_item_get/set_label)
* Tue May 26 2009 Toni Graffy <toni@links2linux.de> - 0.04.5.1-0.pm.1
- update to 0.04.5.1
  * fix wrong porthandling in dsp
  * add latency menu by James Warden
  * impruve midi out
* Thu May 21 2009 Toni Graffy <toni@links2linux.de> - 0.04.4.1-0.pm.1
- update to 0.04.4.1
- Some new effect's in the amp section, overworked tuner and midi out.
* Wed May  6 2009 Toni Graffy <toni@links2linux.de> - 0.04.3.1-0.pm.1
- update to 0.04.3.1
* Tue May  5 2009 Toni Graffy <toni@links2linux.de> - 0.04.2.1-0.pm.1
- update to 0.04.2.1
* Tue Apr 28 2009 Toni Graffy <toni@links2linux.de> - 0.04.1.1-0.pm.1
- update to 0.04.1.1
* Thu Apr 23 2009 Toni Graffy <toni@links2linux.de> - 0.04.0.1-0.pm.1
- update to 0.04.0.1
* Thu Mar 26 2009 Toni Graffy <toni@links2linux.de> - 0.03.9.1-0.pm.1
- update to 0.03.9.1
* Wed Mar 18 2009 Toni Graffy <toni@links2linux.de> - 0.03.8.1-0.pm.1
- update to 0.03.8.1
- added sub-package ladspa-guitarix
* Wed Feb 11 2009 Toni Graffy <toni@links2linux.de> - 0.03.7.1-0.pm.1
- update to 0.03.7.1
* Thu Feb  5 2009 Toni Graffy <toni@links2linux.de> - 0.03.6.1-0.pm.1
- update to 0.03.6.1
* Wed Feb  4 2009 Toni Graffy <toni@links2linux.de> - 0.03.5.1-0.pm.1
- update to 0.03.5.1
* Tue Feb  3 2009 Toni Graffy <toni@links2linux.de> - 0.03.4.1-0.pm.1
- update to 0.03.4.1
* Wed Jan 14 2009 Toni Graffy <toni@links2linux.de> - 0.03.3.1-0.pm.1
- update to 0.03.3.1
* Thu Dec  4 2008 Toni Graffy <toni@links2linux.de> - 0.03.a-0.pm.1
- update to 0.03.a
* Sun Nov 23 2008 Toni Graffy <toni@links2linux.de> - 0.03.0-0.pm.1
- update to 0.03.0
* Mon Nov 10 2008 Toni Graffy <toni@links2linux.de> - 0.02.9a-0.pm.1
- update to 0.02.9a
* Sat Nov  8 2008 Toni Graffy <toni@links2linux.de> - 0.02.9-0.pm.1
- update to 0.02.9
* Thu Nov  6 2008 Toni Graffy <toni@links2linux.de> - 0.02.8-0.pm.1
- update to 0.02.8
* Sun Nov  2 2008 Toni Graffy <toni@links2linux.de> - 0.02.7-0.pm.1
- update to 0.02.7
* Fri Aug  8 2008 Toni Graffy <toni@links2linux.de> - 0.02.4-0.pm.1
- initial package 0.02.4
